@@ -47,12 +47,17 @@ def test_get_all_yahoo_fantasy_game_keys(yahoo_query, yahoo_data, game_code, gam
         None
 
     """
-    query_result_data = yahoo_data.save(game_code + "-game_keys",
-                                        yahoo_query.get_all_yahoo_fantasy_game_keys)
+    query_result_data = yahoo_data.save(
+        f"{game_code}-game_keys",
+        yahoo_query.get_all_yahoo_fantasy_game_keys
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(game_code + "-game_keys")
+    loaded_result_data = yahoo_data.load(
+        f"{game_code}-game_keys",
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(f"{prettify_data(loaded_result_data)}\n----------\n")
 
@@ -88,11 +93,18 @@ def test_get_current_game_info(yahoo_query, yahoo_data, data_dir, season, game_i
         None
 
     """
-    query_result_data = yahoo_data.save("current-game-info", yahoo_query.get_current_game_info)
+    query_result_data = yahoo_data.save(
+        "current-game-info",
+        yahoo_query.get_current_game_info
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load("current-game-info", Game)
+    loaded_result_data = yahoo_data.load(
+        "current-game-info",
+        Game,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -110,11 +122,18 @@ def test_get_current_game_metadata(yahoo_query, yahoo_data, data_dir, season, ga
         None
 
     """
-    query_result_data = yahoo_data.save("current-game-metadata", yahoo_query.get_current_game_metadata)
+    query_result_data = yahoo_data.save(
+        "current-game-metadata",
+        yahoo_query.get_current_game_metadata
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load("current-game-metadata", Game)
+    loaded_result_data = yahoo_data.load(
+        "current-game-metadata",
+        Game,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -133,13 +152,21 @@ def test_get_game_info_by_game_id(yahoo_query, yahoo_data, data_dir, season, gam
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-info",
-                                        yahoo_query.get_game_info_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-info",
+        yahoo_query.get_game_info_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-info", Game, new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-info",
+        Game,
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -158,13 +185,21 @@ def test_get_game_metadata_by_game_id(yahoo_query, yahoo_data, data_dir, season,
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-metadata",
-                                        yahoo_query.get_game_metadata_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-metadata",
+        yahoo_query.get_game_metadata_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-metadata", Game, new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-metadata",
+        Game,
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -201,13 +236,20 @@ def test_get_game_weeks_by_game_id(yahoo_query, yahoo_data, data_dir, season, ga
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-weeks",
-                                        yahoo_query.get_game_weeks_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-weeks",
+        yahoo_query.get_game_weeks_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-weeks", new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-weeks",
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -226,14 +268,21 @@ def test_get_game_stat_categories_by_game_id(yahoo_query, yahoo_data, data_dir,
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-stat_categories",
-                                        yahoo_query.get_game_stat_categories_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-stat_categories",
+        yahoo_query.get_game_stat_categories_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-stat_categories", StatCategories,
-                                         new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-stat_categories",
+        StatCategories,
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
@@ -252,13 +301,20 @@ def test_get_game_position_types_by_game_id(yahoo_query, yahoo_data, data_dir, s
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-position_types",
-                                        yahoo_query.get_game_position_types_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-position_types",
+        yahoo_query.get_game_position_types_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-position_types", new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-position_types",
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
@@ -277,14 +333,20 @@ def test_get_game_roster_positions_by_game_id(yahoo_query, yahoo_data, data_dir,
 
     """
     new_data_dir = data_dir / str(season)
-    query_result_data = yahoo_data.save(str(game_id) + "-game-roster_positions",
-                                        yahoo_query.get_game_roster_positions_by_game_id,
-                                        params={"game_id": game_id}, new_data_dir=new_data_dir)
+    query_result_data = yahoo_data.save(
+        f"{game_id}-game-roster_positions",
+        yahoo_query.get_game_roster_positions_by_game_id,
+        params={"game_id": game_id},
+        new_data_dir=new_data_dir
+    )
     if show_log_output:
         logger.info(prettify_data(query_result_data))
 
-    loaded_result_data = yahoo_data.load(str(game_id) + "-game-roster_positions",
-                                         new_data_dir=new_data_dir)
+    loaded_result_data = yahoo_data.load(
+        f"{game_id}-game-roster_positions",
+        new_data_dir=new_data_dir,
+        all_output_as_json_str=yahoo_query.all_output_as_json_str
+    )
     if show_log_output:
         logger.info(prettify_data(loaded_result_data))
 
